@@ -30,6 +30,7 @@
 #include <TelepathyQt/AbstractClient>
 #include <TelepathyQt/TextChannel>
 #include <TelepathyQt/PendingChannelRequest>
+#include <TelepathyQt/PendingReady>
 
 #include <QQmlEngine>
 
@@ -38,6 +39,8 @@ TelepathyManager::TelepathyManager(QObject *parent)
 {
     Tp::registerTypes();
 
+    m_isReady = false;
+
     m_accountFactory = Tp::AccountFactory::create(QDBusConnection::sessionBus(),
                                                   Tp::Features() << Tp::Account::FeatureCore
                                                                  << Tp::Account::FeatureProfile
@@ -53,6 +56,16 @@ TelepathyManager::TelepathyManager(QObject *parent)
     m_channelFactory = Tp::ChannelFactory::create(QDBusConnection::sessionBus());
 
     m_accountManager = Tp::AccountManager::create(m_accountFactory, m_connectionFactory, m_channelFactory, m_contactFactory);
+    connect(m_accountManager->becomeReady(), &Tp::PendingReady::finished, [=](Tp::PendingOperation *op) {
+        if (op->isError()) {
+            qWarning() << "AccountManager failed to become ready!" << op->errorMessage();
+            return;
+        }
+
+        m_isReady = true;
+
+        Q_EMIT ready();
+    });
 }
 
 TelepathyManager::~TelepathyManager()
@@ -172,6 +185,11 @@ bool TelepathyManager::canSendFiles() const
     return !QStandardPaths::findExecutable(QLatin1String("ktp-send-file")).isEmpty();
 }
 
+bool TelepathyManager::isReady() const
+{
+    return m_isReady;
+}
+
 void TelepathyManager::openDialUi() const
 {
     KToolInvocation::kdeinitExec(QLatin1String("ktp-dialout-ui"));
