@@ -31,8 +31,8 @@ class PendingTpLoggerSearch : public KTp::PendingLoggerSearch
     Q_OBJECT
 
   public:
-    explicit PendingTpLoggerSearch(const QString& term, QObject* parent = 0);
-    virtual ~PendingTpLoggerSearch();
+    explicit PendingTpLoggerSearch(const QString& term, QObject* parent = nullptr);
+    ~PendingTpLoggerSearch() override;
 
   private Q_SLOTS:
     void searchFinished(Tpl::PendingOperation *op);
