@@ -39,7 +39,7 @@ class KTPCOMMONINTERNALS_EXPORT ContactInfoDialog : public QDialog
     Q_OBJECT
 
   public:
-    explicit ContactInfoDialog(const Tp::AccountPtr &account, const Tp::ContactPtr &contact, QWidget *parent = 0);
+    explicit ContactInfoDialog(const Tp::AccountPtr &account, const Tp::ContactPtr &contact, QWidget *parent = nullptr);
     ~ContactInfoDialog() override;
 
   protected:
